@@ -35,3 +35,7 @@ async def _(event):
 @callback("welcomehelp")
 async def _(event):
     await event.edit(f"{welcomehelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+
+@callback("fedhelp")
+async def _(event):
+    await event.edit(f"{fedhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
